/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter;

import java.util.ArrayList;
import java.util.Collection;

/**
 * Allgemeiner Fehler bei der Ausführung eines UdaInterpreters.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class UdaInterpreterException extends Exception {

	/**
	 * Versions-ID für die Serialisierung des Objekts.
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * die Liste der aufgetretenen Fehler.
	 */
	private final Collection<UdaParserFehler> fehlerListe = new ArrayList<>();

	/**
	 * Konstruktor.<br>
	 * Die Funktion erzeugt eine Instanz der Klasse und initialisiert diese mit
	 * den übergebenen Fehlereinträgen.
	 *
	 * @param fehler
	 *            die Liste der initialen Fehler
	 */
	public UdaInterpreterException(final Collection<UdaParserFehler> fehler) {
		this.fehlerListe.addAll(fehler);
	}

	/**
	 * Konstruktor.<br>
	 * Die Funktion erzeugt eine Instanz der Klasse und initialisiert diese mit
	 * dem übergebenen Fehlereintrag.
	 *
	 * @param fehler
	 *            der initiale Fehler
	 */
	public UdaInterpreterException(final UdaParserFehler fehler) {
		this.fehlerListe.add(fehler);
	}

	/**
	 * {@inheritDoc}.<br>
	 * Es wird die Liste der innerhalb des Objekts enthalten Fehlermeldungen als
	 * Zeichenkette ausgegeben.
	 *
	 * @see java.lang.Throwable#toString()
	 */
	@Override
	public String toString() {
		final StringBuffer buffer = new StringBuffer("Skript-Parser-Fehler");
		buffer.append("\n====================\n");
		for (final UdaParserFehler fehler : fehlerListe) {
			buffer.append(fehler);
			buffer.append("\n");
		}

		return buffer.toString();
	}

	/**
	 * liefert die Liste der enthaltenen Fehlereinträge.
	 *
	 * @return die Liste
	 */
	public Collection<UdaParserFehler> getFehlerListe() {
		return fehlerListe;
	}

}
