/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.dav;

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.config.ConfigurationChangeException;
import de.bsvrz.dav.daf.main.config.MutableSet;
import de.bsvrz.dav.daf.main.config.ObjectSet;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.ibv.uda.interpreter.daten.container.Feld;
import de.bsvrz.ibv.uda.interpreter.daten.container.UdaContainer;
import de.bsvrz.ibv.uda.interpreter.daten.fehler.KonfigurationsFehler;
import de.bsvrz.ibv.uda.interpreter.daten.fehler.UdaFehlerSubtyp;
import de.bsvrz.sys.funclib.bitctrl.interpreter.logik.LogischerWert;

/**
 * Repräsentation eines Mengenobjekts ({@link ObjectSet}) innerhalb eines
 * Uda-Interpreters.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class MengenObjekt extends KonfigurationsObjekt {

	/**
	 * Konstruktor.<br>
	 *
	 * @param verbindung
	 *            die verwendete Datenverteilerverbindung
	 * @param objekt
	 *            das zu Grund liegende Mengenobjekt
	 */
	public MengenObjekt(final ClientDavInterface verbindung, final ObjectSet objekt) {
		super(verbindung, objekt);
	}

	/**
	 * die Funktion fügt ein Objekt in eine Menge ein.
	 *
	 * @param objekt
	 *            das einzufügende Objekt
	 */
	public void einfuegenObjekt(final SystemObjectObjekt objekt) {
		try {
			getObjekt().add(objekt.getObjekt());
		} catch (final ConfigurationChangeException e) {
			throw new KonfigurationsFehler(UdaFehlerSubtyp.UNBEKANNT, e.getMessage());
		}
	}

	/**
	 * entfernt ein Objekt aus einer Menge.
	 *
	 * @param objekt
	 *            das zu entfernende Objekt
	 */
	public void entferneObjekt(final SystemObjectObjekt objekt) {
		try {
			getObjekt().remove(objekt.getObjekt());
		} catch (final ConfigurationChangeException e) {
			throw new KonfigurationsFehler(UdaFehlerSubtyp.UNBEKANNT, e.getMessage());
		}
	}

	/**
	 * liefert einen {@link UdaContainer} mit den Elementen des MengenObjekts.
	 *
	 * @return der Container mit den Objekten
	 */
	public UdaContainer getMengenObjekte() {
		final Feld result = new Feld();
		for (final SystemObject obj : getObjekt().getElements()) {
			result.einfuegen(0, DavDaten.erzeugeObjekt(getVerbindung(), obj));
		}
		return result;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.daten.dav.SystemObjectObjekt#getObjekt()
	 */
	@Override
	public ObjectSet getObjekt() {
		return (ObjectSet) super.getObjekt();
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.daten.dav.KonfigurationsObjekt#getStrukturElement(java.lang.String)
	 */
	@Override
	public Object getStrukturElement(final String name) {
		Object result = null;
		final ObjectSet object = getObjekt();

		if ("objekte".equals(name)) {
			result = getMengenObjekte();
		} else if ("gültigeObjekte".equals(name)) {
			result = new Feld();
			for (final SystemObject obj : object.getElements()) {
				if (obj.isValid()) {
					((Feld) result).einfuegen(0, DavDaten.erzeugeObjekt(getVerbindung(), obj));
				}
			}
		} else if ("dynamisch".equals(name)) {
			result = LogischerWert.valueOf(getObjekt() instanceof MutableSet);
		}

		if (result == null) {
			result = super.getStrukturElement(name);
		}

		return result;
	}
}
