/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.fehler;

import java.util.List;

import de.bsvrz.ibv.uda.interpreter.AbstractUdaHandler;
import de.bsvrz.sys.funclib.bitctrl.interpreter.HandlerValidation;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Operator;
import de.bsvrz.sys.funclib.bitctrl.interpreter.logik.LogischerWert;
import de.bsvrz.sys.funclib.debug.Debug;

/**
 * Handler zur Ausführung von Operationen mit Fehlerobjekten.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class FehlerHandler extends AbstractUdaHandler {

	private static final Debug LOGGER = Debug.getLogger();

	/**
	 * {@inheritDoc}.
	 *
	 * @return die Liste der unterstützten Operatoren
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Handler#getHandledOperators()
	 */
	@Override
	public Operator[] getHandledOperators() {
		return FehlerOperatoren.OPERATOREN;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Handler#validiereHandler(de.bsvrz.sys.funclib.bitctrl.interpreter.Operator,
	 *      java.util.List)
	 */
	@Override
	public HandlerValidation validiereHandler(final Operator operator, final List<? extends Object> operanden) {
		boolean anzahlOk = false;
		boolean typOk = false;
		if (isKonstruktor(operator)) {
			if (operanden.size() <= 3) {
				anzahlOk = true;
				Object zusatzText = null;
				Object fehler = null;
				if (operanden.size() > 0) {
					if (operanden.get(0) instanceof UdaFehlerSubtyp) {
						if (operanden.size() > 1) {
							zusatzText = operanden.get(1);
						}
						if (operanden.size() > 2) {
							fehler = operanden.get(2);
						}
					} else {
						zusatzText = operanden.get(0);
						if (operanden.size() > 1) {
							fehler = operanden.get(1);
						}
					}
				}

				if (((zusatzText == null) || (zusatzText instanceof String))
						&& ((fehler == null) || (fehler instanceof UdaFehler))) {
					typOk = true;
				}
			}
		} else if (FehlerOperatoren.MELDUNG.equals(operator)) {
			if (operanden.size() >= 1) {
				anzahlOk = true;
				if (operanden.get(0) instanceof UdaFehler) {
					if ((operanden.size() == 1) || ((operanden.size() == 2) && (operanden.get(1) instanceof Number))) {
						typOk = true;
					}
				}
			}
		} else if (FehlerOperatoren.IST_FEHLER.equals(operator)) {
			if (operanden.size() == 1) {
				anzahlOk = true;
				typOk = true;
			}
		} else if (FehlerOperatoren.FEHLER_TYP_KONSTRUKTOR.equals(operator)) {
			if (operanden.size() == 1) {
				anzahlOk = true;
				typOk = true;
			}
		}
		return new HandlerValidation(anzahlOk, typOk);
	}

	/**
	 * ermittelt, ob der übergebene Operator ein Konstruktor ist.
	 *
	 * @param operator
	 *            der Operator, der geprüft werden soll
	 * @return "wahr", wenn es sich um einen Konstruktor handelt.
	 */
	private boolean isKonstruktor(final Operator operator) {
		boolean result = false;
		if (FehlerOperatoren.ARGUMENT_FEHLER_KONSTRUKTOR.equals(operator)) {
			result = true;
		} else if (FehlerOperatoren.ARITHMETISCHER_FEHLER_KONSTRUKTOR.equals(operator)) {
			result = true;
		} else if (FehlerOperatoren.CONTAINERZUGRIFFS_FEHLER_KONSTRUKTOR.equals(operator)) {
			result = true;
		} else if (FehlerOperatoren.DATENZUGRIFFS_FEHLER_KONSTRUKTOR.equals(operator)) {
			result = true;
		} else if (FehlerOperatoren.KONFIGURATIONS_FEHLER_KONSTRUKTOR.equals(operator)) {
			result = true;
		} else if (FehlerOperatoren.OBJEKTZUGRIFFS_FEHLER_KONSTRUKTOR.equals(operator)) {
			result = true;
		} else if (FehlerOperatoren.SYMBOLUNDEFINIERT_FEHLER_KONSTRUKTOR.equals(operator)) {
			result = true;
		} else if (FehlerOperatoren.FEHLER_KONSTRUKTOR.equals(operator)) {
			result = true;
		}
		return result;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Handler#perform(de.bsvrz.sys.funclib.bitctrl.interpreter.Operator,
	 *      java.util.List)
	 */
	@Override
	public Object perform(final Operator operator, final List<Object> operanden) {
		erzeugeHandlerFehler(operator, operanden);
		Object result = null;
		try {
			if (isKonstruktor(operator)) {
				UdaFehlerSubtyp subtyp = UdaFehlerSubtyp.UNBEKANNT;
				String meldung = null;
				UdaFehler fehler = null;
				if (operanden.size() > 0) {
					if (operanden.get(0) instanceof UdaFehlerSubtyp) {
						subtyp = (UdaFehlerSubtyp) operanden.get(0);
						if (operanden.size() > 1) {
							meldung = (String) operanden.get(1);
						}
						if (operanden.size() > 2) {
							fehler = (UdaFehler) operanden.get(2);
						}
					} else {
						meldung = (String) operanden.get(0);
						if (operanden.size() > 1) {
							fehler = (UdaFehler) operanden.get(1);
						}
					}
				}

				if (FehlerOperatoren.ARGUMENT_FEHLER_KONSTRUKTOR.equals(operator)) {
					result = new ArgumentFehler(subtyp, meldung, fehler);
				} else if (FehlerOperatoren.ARITHMETISCHER_FEHLER_KONSTRUKTOR.equals(operator)) {
					result = new ArithmetischerFehler(subtyp, meldung, fehler);
				} else if (FehlerOperatoren.CONTAINERZUGRIFFS_FEHLER_KONSTRUKTOR.equals(operator)) {
					result = new ContainerZugriffsFehler(subtyp, meldung, fehler);
				} else if (FehlerOperatoren.DATENZUGRIFFS_FEHLER_KONSTRUKTOR.equals(operator)) {
					result = new DatenZugriffsFehler(subtyp, meldung, fehler);
				} else if (FehlerOperatoren.FEHLER_KONSTRUKTOR.equals(operator)) {
					result = new Fehler(meldung, fehler);
				} else if (FehlerOperatoren.KONFIGURATIONS_FEHLER_KONSTRUKTOR.equals(operator)) {
					result = new KonfigurationsFehler(subtyp, meldung, fehler);
				} else if (FehlerOperatoren.OBJEKTZUGRIFFS_FEHLER_KONSTRUKTOR.equals(operator)) {
					result = new ObjektZugriffsFehler(subtyp, meldung, fehler);
				} else if (FehlerOperatoren.SYMBOLUNDEFINIERT_FEHLER_KONSTRUKTOR.equals(operator)) {
					result = new SymbolUndefiniertFehler(subtyp, meldung, fehler);
				}

			} else if (FehlerOperatoren.MELDUNG.equals(operator)) {
				if (operanden.size() > 0) {
					int size = Integer.MAX_VALUE;
					if (operanden.size() > 1) {
						size = ((Number) operanden.get(1)).intValue();
					}
					result = ((UdaFehler) operanden.get(0)).meldungen(size);
				}
			} else if (FehlerOperatoren.IST_FEHLER.equals(operator)) {
				result = LogischerWert.valueOf(operanden.get(0) instanceof UdaFehler);
			} else if (FehlerOperatoren.FEHLER_TYP_KONSTRUKTOR.equals(operator)) {
				try {
					result = UdaFehlerSubtyp.valueOf(operanden.get(0).toString());
				} catch (final IllegalArgumentException e) {
					final String message = "Es exisistert kein Fehlertyp mit der Bezeichnung "
							+ operanden.get(0);
					FehlerHandler.LOGGER.error(message, e);
					throw new ArgumentFehler(UdaFehlerSubtyp.ARGUMENTE,
							message);
				}
			}
		} catch (@SuppressWarnings("unused") final ClassCastException e) {
			throw new ArgumentFehler(UdaFehlerSubtyp.ARGUMENTE);
		}

		return result;
	}
}
