/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.trend;

import de.bsvrz.sys.funclib.bitctrl.interpreter.Operator;

/**
 * Die Operatoren für die Verwendung von Vergangenheits-Objekten (Trends).
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public final class TrendOperatoren {

	/**
	 * Konstruktor zum Anlegen eines Trendobjekts.
	 */
	public static final Operator KONSTRUKTOR = Operator.getOperator("Trend");

	/**
	 * Funktion zum Ermitteln des Bezugs des Trends.<br>
	 * Der Bezug wird als Zeichenkette beim Anlegen eines Trendobjekts angegeben
	 * und hat keine weitere Bedeutung.
	 */
	public static final Operator BEZUG = Operator.getOperator("bezug");

	/**
	 * Funktion zum Ermitteln bzw. Setzen des zuletzt in das Trendobjekt
	 * eingefügten Wertes.
	 */
	public static final Operator WERT = Operator.getOperator("wert");

	/**
	 * Funktion zum Ermitteln des Zeitstempels des zuletzt in das Trendobjekt
	 * eingefügten Wertes.
	 */
	public static final Operator ZEIT = Operator.getOperator("zeit");

	/**
	 * Die Funktion ermittelt die Anzahl der Werte innerhalb eines Trendobjekts,
	 * die streng monoton fallend sind.
	 */
	public static final Operator MAXFALLEND = Operator.getOperator("maxFallend");

	/**
	 * Die Funktion ermittelt die Anzahl der Werte innerhalb eines Trendobjekts,
	 * die streng monoton steigend sind.
	 */
	public static final Operator MAXSTEIGEND = Operator.getOperator("maxSteigend");

	/**
	 * Die Funktion ermittelt die Anzahl der Werte innerhalb eines Trendobjekts,
	 * die konstant sind.
	 */
	public static final Operator MAXKONSTANT = Operator.getOperator("maxKonstant");

	/**
	 * Die Funktion ermittelt, ob die Werte eines Trendobjekts monoton steigend
	 * sind.
	 */
	public static final Operator STEIGEND = Operator.getOperator("steigend");

	/**
	 * Die Funktion ermittelt, ob die Werte eines Trendobjekts monoton fallend
	 * sind.
	 */
	public static final Operator FALLEND = Operator.getOperator("fallend");

	/**
	 * Die Funktion ermittelt, ob die Werte eines Trendobjekts konstant sind.
	 */
	public static final Operator KONSTANT = Operator.getOperator("konstant");

	/**
	 * Die Funktion liefert die Anzahl der innerhalb des Trendobjekts
	 * gespeicherten Eintr&auml;ge.
	 */
	public static final Operator ANZAHL = Operator.getOperator("anzahl");

	/**
	 * die Liste aller unterst&uuml;tzten Operatoren und Funktionen zur Arbeit
	 * mit Trendobjekten.
	 */
	public static final Operator[] TREND_OPERATOREN = { TrendOperatoren.KONSTRUKTOR, TrendOperatoren.BEZUG,
			TrendOperatoren.WERT, TrendOperatoren.ZEIT, TrendOperatoren.MAXFALLEND, TrendOperatoren.MAXSTEIGEND,
			TrendOperatoren.MAXKONSTANT, TrendOperatoren.STEIGEND, TrendOperatoren.FALLEND, TrendOperatoren.KONSTANT,
			TrendOperatoren.ANZAHL };

	/** privater Konstruktor für Utility-Klasse. */
	private TrendOperatoren() {
		super();
	}
}
