/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.parser;

import antlr.CommonAST;
import antlr.Token;

/**
 * Knoten innerhalb des AST mit zusätzlichen Informationen zur Zeilennummer.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class CommonASTWithLines extends CommonAST {
	/**
	 * Versions-ID für die Serialisierung des Objekts.
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * Nummer der Zeile, in der der Knoten im Quelltext beschrieben ist.
	 */
	private int line;

	/**
	 * Standardkonstruktor.
	 */
	public CommonASTWithLines() {
		super();
	}

	/**
	 * Konstruktor mit Token aus dem Lexer.
	 *
	 * @param tok
	 *            das Token
	 */
	public CommonASTWithLines(final Token tok) {
		super(tok);
	}

	/**
	 * initialisiert den Knoten mit dem übergebenen Token.
	 *
	 * @param tok
	 *            das Token
	 * @see antlr.CommonAST#initialize(antlr.Token)
	 */
	@Override
	public void initialize(final Token tok) {
		super.initialize(tok);
		line = tok.getLine();
	}

	/**
	 * liefert die Zeilennummer.
	 *
	 * @return die Nummer der Zeile
	 * @see antlr.BaseAST#getLine()
	 */
	@Override
	public int getLine() {
		return line;
	}
}
