/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.uda.data;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import de.bsvrz.sys.funclib.bitctrl.daf.AbstractDavZustand;

/**
 * die Repräsentation des Bearbeitungszutandes für ein Uda-Skript.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public final class SkriptZustand extends AbstractDavZustand {

	/**
	 * Versions-ID für die Serialisierung des Objekts.
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * die Liste aller definierten Zustände.
	 */
	private static final Map<Integer, SkriptZustand> ZUSTAENDE = new HashMap<>();

	/**
	 * das Skript wurde angelegt.
	 */
	public static final SkriptZustand ANGELEGT = new SkriptZustand(0, "Angelegt");

	/**
	 * das Skript befindet sich in Bearbeitung.
	 */
	public static final SkriptZustand IN_BEARBEITUNG = new SkriptZustand(1, "In Bearbeitung");

	/**
	 * das Skript wurde zur Ausführung freigegeben.
	 */
	public static final SkriptZustand FREIGEGEBEN = new SkriptZustand(2, "Freigegeben");

	/**
	 * Konstruktor.<br>
	 * Die Funktion erzeugt ein Zustandsobjekt für die angegebenen Werte für
	 * Code und Bezeichnung.
	 *
	 * @param code
	 *            der Code
	 * @param name
	 *            der Name
	 */
	private SkriptZustand(final int code, final String name) {
		super(code, name);
		SkriptZustand.ZUSTAENDE.put(code, this);
	}

	/**
	 * liefert den Zustand für den übergebenen Code.
	 *
	 * @param searchedCode
	 *            der Code
	 * @return der Zustand
	 */
	public static SkriptZustand getZustand(final int searchedCode) {
		return SkriptZustand.ZUSTAENDE.get(searchedCode);
	}

	/**
	 * liefert die Liste aller definierter Skriptzustände.
	 *
	 * @return die Liste
	 */
	public static Collection<SkriptZustand> getElemente() {
		return SkriptZustand.ZUSTAENDE.values();
	}
}
