/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.verwaltung.protokoll;

import java.util.Collection;
import java.util.HashMap;

import de.bsvrz.sys.funclib.bitctrl.daf.AbstractDavZustand;

/**
 * die Typen für Protokolle, die beim der Ausführung eines Skripts erstellt
 * werden können.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public final class ProtokollTyp extends AbstractDavZustand {
	/**
	 * Versions-ID für die Serialisierung des Objekts.
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * die Menge aller definierter Protokolltypen.
	 */
	private static final HashMap<Integer, ProtokollTyp> TYPEN = new HashMap<>();

	/**
	 * Ausgabe der Protokolldaten auf die Konsole (Standardausgabe).
	 */
	public static final ProtokollTyp KONSOLE = new ProtokollTyp(0, "Konsole");

	/**
	 * Ausgabe der Protokolldaten in eine per Namen definierte Datei.
	 */
	public static final ProtokollTyp DATEI = new ProtokollTyp(1, "Datei");

	/**
	 * Ausgabe der Protokolldaten in eine Logdatei unter Verwendung der
	 * Java-Standard-Logging-Mechanismen, d.h. mehrere Dateien mit Begrenzung
	 * der Größe als Ringpuffer.
	 */
	public static final ProtokollTyp LOGGING = new ProtokollTyp(2, "Logging");

	/**
	 * Ausgabe der Protokolldaten über eine dem Skriptlauf zugeordnete
	 * Attributgruppe mit einer definierbaren Anzahl von Meldungstexten.
	 */
	public static final ProtokollTyp DAV = new ProtokollTyp(3, "Dav");

	/**
	 * Privater Konstruktor, der das zusätzliche Anlegen von Objekten diesn Typs
	 * verhindern soll.
	 *
	 * @param code
	 *            der Code für den Zustand
	 * @param name
	 *            der Name des Zustands
	 */
	private ProtokollTyp(final int code, final String name) {
		super(code, name);
		ProtokollTyp.TYPEN.put(code, this);
	}

	/**
	 * liefert eine Liste aller definierten Protokolltypen.
	 *
	 * @return die Typen
	 */
	public static Collection<ProtokollTyp> getElemente() {
		return ProtokollTyp.TYPEN.values();
	}

	/**
	 * liefert den Typ für den übergebenen Code.
	 *
	 * @param gesucht
	 *            der Code des gesuchten Typs
	 * @return der Typ oder <i>null</i>, wenn kein solcher existiert
	 */
	public static ProtokollTyp getTyp(final Integer gesucht) {
		return ProtokollTyp.TYPEN.get(gesucht);
	}
}
