/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.fuzzy;

import de.bsvrz.iav.fuzzylib.fuzzylib.FuzzyVariable;
import de.bsvrz.ibv.uda.interpreter.ausdruck.Struktur;
import de.bsvrz.ibv.uda.interpreter.daten.container.Container;
import de.bsvrz.ibv.uda.interpreter.daten.container.Feld;
import de.bsvrz.sys.funclib.bitctrl.interpreter.InterpreterException;
import de.bsvrz.sys.funclib.bitctrl.interpreter.NichtWert;

/**
 * Repräsentation eines Fuzzy-Wertes in einem Uda-Interpreter.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class UdaFuzzyWert implements Struktur, Container {

	/**
	 * die zu Grunde liegende Fuzzy-Variable.
	 */
	private final FuzzyVariable variable;

	/**
	 * Konstruktor.<br>
	 *
	 * @param variable
	 *            die zu Grunde liegende {@link FuzzyVariable}
	 */
	public UdaFuzzyWert(final FuzzyVariable variable) {
		super();
		this.variable = variable;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.ausdruck.Struktur#getStrukturElement(java.lang.String)
	 * @see #setStrukturElement(String, Object)
	 */
	@Override
	public Object getStrukturElement(final String name) {
		Object result = null;
		result = variable.getTerm(name);
		if (result == null) {
			result = NichtWert.NICHTWERT;
		}
		return result;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.ausdruck.Struktur#setStrukturElement(java.lang.String,
	 *      java.lang.Object)
	 * @see #getStrukturElement(String)
	 */
	@Override
	public void setStrukturElement(final String name, final Object daten) {
		variable.setTerm(name, ((Number) daten).floatValue());
	}

	/**
	 * liefert die zu Grunde liegende Fuzzy-Variable.
	 *
	 * @return die Variable
	 */
	public FuzzyVariable getVariable() {
		return variable;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		if (variable != null) {
			return variable.toString();
		}
		return null;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.daten.container.Container#getContainerElement(int)
	 * @see #setContainerElement(int, Object)
	 */
	@Override
	public Object getContainerElement(final int index) {
		final Feld feld = new Feld();
		for (final String termName : variable.getTermnamen()) {
			feld.einfuegen(0, new UdaTerm(variable.getTerm(termName)));
		}
		return feld.getContainerElement(index);
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.daten.container.Container#setContainerElement(int,
	 *      java.lang.Object)
	 * @see #getContainerElement(int)
	 */
	@Override
	public void setContainerElement(final int index, final Object daten) {
		throw new InterpreterException("Ein Element eines Fuzzywertes kann nicht direkt gesetzt werden");
	}
}
